@@ -1,4 +1,4 @@
-from b_lambda_layer_common.source.python.b_lambda_layer_common.util.do_not_update import DoNotUpdate
+from b_lambda_layer_common.util.do_not_update import DoNotUpdate
 
 
 def test_FUNC_init_WITH_no_params_EXPECT_class_initiated() -> None:
